=====
Lenny
=====

( ͡° ͜ʖ ͡°)
--------

Generates random `lenny faces`_.

Symbols pulled from `http://textsmili.es`__ by `@polyfloyd`_ and from `https://textfac.es/`.

Installation
------------
.. code-block:: python

    pip install lenny

Usage
-----
.. code-block:: python

    >>> from lenny import lenny
    >>> lenny()
    'ᕦ(ළ‿ළ)ᕥ'
    >>> lenny()
    'ᑫ⇀﹏↼ᑷ'
    >>> lenny()
    'ᕕ(xᨓx)ᕗ'

.. _lenny faces: http://knowyourmeme.com/memes/%CD%A1-%CD%9C%CA%96-%CD%A1-lenny-face
.. __: http://textsmili.es
.. _@polyfloyd: https://twitter.com/polyfloyd
